package com.example.demo

import org.springframework.boot.autoconfigure.SpringBootApplication
import org.springframework.boot.runApplication
import org.springframework.jdbc.core.namedparam.NamedParameterJdbcTemplate
import org.springframework.stereotype.Repository
import org.springframework.transaction.annotation.EnableTransactionManagement
import org.springframework.transaction.annotation.Transactional
import org.springframework.web.bind.annotation.GetMapping
import org.springframework.web.bind.annotation.RequestMapping
import org.springframework.web.bind.annotation.RestController

@EnableTransactionManagement
@SpringBootApplication
class DemoApplication

fun main(args: Array<String>) {
    runApplication<DemoApplication>(*args)
}

@RestController
@Transactional
@RequestMapping("/demos")
class DemoController(private val demoRepository: DemoRepository) {
    @GetMapping
    fun getDemos() = demoRepository.getDemos()
}

@Repository
class DemoRepository(private val jdbcTemplate: NamedParameterJdbcTemplate) {
    fun getDemos(): List<Demo> {
        return jdbcTemplate.query("select id, name from demo") { rs, rowNum ->
            Demo(rs.getLong("id"), rs.getString("name"))
        }
    }
}

data class Demo(val id: Long, val name: String)
